import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormControl, FormGroup, Validators } from '@angular/forms';
import { ActivatedRoute } from '@angular/router';
import { PassengerService } from '../../services/passenger-service.service';
import { EMPTY_PASSENGER, Passenger } from '../../interfaces/passenger.interface';

@Component({
  selector: 'app-passenger-add',
  templateUrl: './passenger-add.component.html',
  styleUrls: ['./passenger-add.component.css']
})
export class PassengerAddComponent implements OnInit {

  public passengerForm: FormGroup = new FormGroup({
    name: new FormControl('', [Validators.required]),
    secondName: new FormControl('', [Validators.required]),
    lastname: new FormControl('', [Validators.required]),
    country: new FormControl('', [Validators.required]),
    city: new FormControl('', [Validators.required]),
    address: new FormControl('', [Validators.required]),
    phone: new FormControl('', [Validators.required]),
    email: new FormControl('', [Validators.required]),
    password: new FormControl('', [Validators.required])
  });

  constructor(
    private activatedRoute: ActivatedRoute,
    private fb: FormBuilder,
    private passengerService: PassengerService) { }


  ngOnInit(): void {
    this.activatedRoute.params.subscribe(param => {
      if (!param['id']) {
        this.buildForm();
        return;
      }

      this.passengerService.getById(param['id'])
        .subscribe(passenger => {
          this.buildForm(passenger);
        });
    });
  }

  buildForm(passenger: Passenger = EMPTY_PASSENGER): void {
    this.passengerForm.get('name')?.setValue(passenger.name);
    this.passengerForm.get('secondName')?.setValue(passenger.secondName);
    this.passengerForm.get('lastname')?.setValue(passenger.lastname);
    this.passengerForm.get('country')?.setValue(passenger.country);
    this.passengerForm.get('city')?.setValue(passenger.city);
    this.passengerForm.get('address')?.setValue(passenger.address);
    this.passengerForm.get('phone')?.setValue(passenger.phone);
    this.passengerForm.get('email')?.setValue(passenger.email);
    this.passengerForm.get('password')?.setValue(passenger.password);
  }

  onSave():void {
    console.log(this.passengerForm.value);
  }

}
