import { ChangeDetectorRef, Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { TableModel } from '../../interfaces/table-model.interface';
import { ResultDelete } from '../../interfaces/result-delete.interface';

@Component({
  selector: 'shared-table',
  templateUrl: './table.component.html',
  styleUrls: ['./table.component.css']
})
export class TableComponent {

  @Output()
  public onReloadData: EventEmitter<void> = new EventEmitter();

  @Output()
  public onDialogResult: EventEmitter<ResultDelete> = new EventEmitter();

  @Input()
  public tableModel: TableModel[] = [];

  @Input()
  public tableData: any[] = [];

  @Input()
  public newRouter: string = '';

  @Input()
  public editRouter: string = '';

  public numberOfItemsPerPage: number = 5;

  public itemsPerPage: number[] = [5, 10, 15];

  public page: number = 1;

  public openDialogDelete: boolean = false;

  public deleteItemId: number = 0;

  get totalPage(): number {
    return this.tableData.length >= this.numberOfItemsPerPage? Math.ceil(this.tableData.length / this.numberOfItemsPerPage) : 1;
  }

  get initItem() {
    return this.tableData.length == 0? 0 : this.totalPage >= 1 || this.tableData.length == 0? ((this.page - 1) * this.numberOfItemsPerPage) + 1 : 0;
  }

  get endItem() {
    return this.totalPage >= 1? this.page != this.totalPage? this.page * this.numberOfItemsPerPage: this.tableData.length : 0;
  }

  get tableDataSelected(): any {
    return this.tableData.filter((_, index) => index + 1 >= this.initItem && index + 1 <= this.endItem);
  }


  nextPage(): void {
    if (this.page === this.totalPage) return;
    this.page += 1;
  }

  prevPage(): void {
    if (this.page === 1) return;
    this.page -= 1;
  }

  getItemsPerPage(value: string): void {
    this.numberOfItemsPerPage = parseInt(value);
  }

  toggleDialogDelete(id: number): void {
    this.deleteItemId = id;
    this.openDialogDelete = !this.openDialogDelete;
  }

  onEmitDialogResult(result: boolean): void {
    this.openDialogDelete = !this.openDialogDelete;
    this.onDialogResult.emit({id: this.deleteItemId, result});
  }

  onEmitReloadData(): void {
    this.onReloadData.emit();
  }
}
